@@ -16,6 +16,7 @@ from jsonschema.exceptions import ValidationError
 from quart import Blueprint, Quart, jsonify
 from quart.views import http_method_funcs
 
+from .marshmallow import MARSHMALLOW, MarshmallowValidationError
 from .cors import crossdomain
 from .resource import Resource
 from .typing import ExpectedDescList, ValidatorTypes
@@ -83,6 +84,8 @@ class BaseRest():
             elif isinstance(base_model_schema, RefResolver):
                 self._ref_resolver = base_model_schema
         self.register_error_handler(ValidationError, self.handle_json_validation_exc)  # pylint: disable=no-member
+        if MARSHMALLOW:
+            self.register_error_handler(MarshmallowValidationError, self.handle_marshmallow_json_validation_exc)  # pylint: disable=no-member
 
     @property
     def title(self) -> str:
@@ -140,6 +143,34 @@ class BaseRest():
             }
         }), HTTPStatus.BAD_REQUEST.value
 
+    @staticmethod
+    def handle_marshmallow_json_validation_exc(error: MarshmallowValidationError
+                                               ) -> Dict[str, Union[str, Dict[str, str]]]:
+        """Function to handle validation errors
+
+        The constructor will register this function to handle a :exc:`~marshmallow.ValidationError`
+        which is thrown by the :mod:`marshmallow` validation routines.
+
+        :param error: The exception that was raised
+        :return: Json message with the validation error
+
+        .. seealso::
+
+           :meth:`quart.Quart.register_error_handler`
+               Registering error handlers with quart
+        """
+        LOGGER.error('request body validation failed, returning error: msg: %s, instance: %r',
+                     error.messages, error.data)
+        err = {
+            'msg': error.messages,
+            'value': error.data
+        }
+        if hasattr(error, 'schema'):
+            err['schema'] = error.schema
+        return jsonify({
+            'message': 'Request Body failed validation',
+            'error': err
+        }), HTTPStatus.BAD_REQUEST
 
     @property
     def resources(self) -> Iterable[Tuple[Resource, str, Iterable[str]]]:
@@ -196,7 +227,7 @@ class BaseRest():
                 setattr(resource, f'_pint_{resource.__name__}_view_wrapper', view_func)
             methods = list(resource.methods)
             self._resources.append((resource, path, methods))
-        super().add_url_rule(path, endpoint, view_func, methods,  # pylint: disable=no-member
+        super().add_url_rule(path, endpoint, view_func, methods=methods,  # pylint: disable=no-member
                              provide_automatic_options=provide_automatic_options, **kwargs)
 
     def param(self, name: str, description: Optional[str] = None, _in: str = 'query', **kwargs: Any) -> Callable:
@@ -496,14 +527,13 @@ class PintBlueprint(BaseRest, Blueprint):
         """Will forward all arguments and keyword arguments to Blueprints"""
         super().__init__(*args, **kwargs)
 
-    # pylint: disable=arguments-differ
-    def register(self, app: Pint, first_registration: bool, *, url_prefix: Optional[str] = None, **kwargs) -> None:
+    def register(self, app: Pint, options: dict, first_registration: bool = False) -> None:
         """override the base :meth:`~quart.Blueprint.register` method to add the resources to the app registering
         this blueprint, then call the parent register method
         """
-        prefix = url_prefix or self.url_prefix or ''
+        prefix = options.get('url_prefix', '') or self.url_prefix or ''
         app.resources.extend([(res, f'{prefix}{path}', methods) for res, path, methods in self._resources])
-        super().register(app, first_registration, url_prefix=url_prefix, **kwargs)
+        super().register(app, options, first_registration)
 
 class OpenApiView(Resource):
     """The :class:`Resource` used for the '/openapi.json' route
